@@ -14,7 +14,13 @@
 # limitations under the License.
 #
 import os
-import mock
+
+# try/except added for compatibility with python < 3.8
+try:
+    from unittest import mock
+    from unittest.mock import AsyncMock
+except ImportError:
+    import mock
 
 import grpc
 from grpc.experimental import aio
@@ -742,7 +748,7 @@ def test_optimize_tours_field_headers():
     # a field header. Set these to a non-empty value.
     request = fleet_routing.OptimizeToursRequest()
 
-    request.parent = "parent/value"
+    request.parent = "parent_value"
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(type(client.transport.optimize_tours), "__call__") as call:
@@ -758,7 +764,7 @@ def test_optimize_tours_field_headers():
     _, _, kw = call.mock_calls[0]
     assert (
         "x-goog-request-params",
-        "parent=parent/value",
+        "parent=parent_value",
     ) in kw["metadata"]
 
 
@@ -772,7 +778,7 @@ async def test_optimize_tours_field_headers_async():
     # a field header. Set these to a non-empty value.
     request = fleet_routing.OptimizeToursRequest()
 
-    request.parent = "parent/value"
+    request.parent = "parent_value"
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(type(client.transport.optimize_tours), "__call__") as call:
@@ -790,7 +796,7 @@ async def test_optimize_tours_field_headers_async():
     _, _, kw = call.mock_calls[0]
     assert (
         "x-goog-request-params",
-        "parent=parent/value",
+        "parent=parent_value",
     ) in kw["metadata"]
 
 
@@ -893,7 +899,7 @@ def test_batch_optimize_tours_field_headers():
     # a field header. Set these to a non-empty value.
     request = fleet_routing.BatchOptimizeToursRequest()
 
-    request.parent = "parent/value"
+    request.parent = "parent_value"
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
@@ -911,7 +917,7 @@ def test_batch_optimize_tours_field_headers():
     _, _, kw = call.mock_calls[0]
     assert (
         "x-goog-request-params",
-        "parent=parent/value",
+        "parent=parent_value",
     ) in kw["metadata"]
 
 
@@ -925,7 +931,7 @@ async def test_batch_optimize_tours_field_headers_async():
     # a field header. Set these to a non-empty value.
     request = fleet_routing.BatchOptimizeToursRequest()
 
-    request.parent = "parent/value"
+    request.parent = "parent_value"
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
@@ -945,7 +951,7 @@ async def test_batch_optimize_tours_field_headers_async():
     _, _, kw = call.mock_calls[0]
     assert (
         "x-goog-request-params",
-        "parent=parent/value",
+        "parent=parent_value",
     ) in kw["metadata"]
 
 
